@@ -5,9 +5,6 @@
 This module provides unit tests for `ptutils.introspection`.
 """
 
-# -----------------------------------------------------------------------------------------------------------------------
-# Main imports
-# -----------------------------------------------------------------------------------------------------------------------
 from ptutils.introspection import get_function, get_functions
 
 
@@ -29,6 +26,7 @@ def dummy_c():
 
 def test_get_function():
     assert get_function('dummy', __name__) is dummy
+    assert get_function('does_not_exist', __name__) is None
 
 
 def test_get_functions():
