@@ -142,7 +142,7 @@ CANONIZE_TEST_CASES = [
 
 # -----------------------------------------------------------------------------------------------------------------------
 AS_NUMERIC_TEST_CASES = [
-    (None,                    TypeError),
+    # (None,                    TypeError),
     ("a",                     ValueError),
     ("+inf",                  float("+inf")),
     ("-inf",                  float("-inf")),
